@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 "check build refs"
 #
-# Copyright (C) 2011-2018 ABINIT Group (Yann Pouillon)
+# Copyright (C) 2011-2020 ABINIT Group (Yann Pouillon)
 #
 # This file is part of the ABINIT software package. For license information,
 # please see the COPYING file in the top-level directory of the ABINIT source
@@ -9,25 +9,17 @@
 #
 from __future__ import unicode_literals, division, print_function, absolute_import
 
+from abirules_tools import find_abinit_toplevel_directory
+
 from time import gmtime,strftime
 
 import os
 import re
 import sys
 
-# ---------------------------------------------------------------------------- #
-def abinit_test_generator():
-  def test_func(abenv):
-     "check build refs"
-     try:
-       return main(abenv.home_dir)
-     except Exception:
-       import sys
-       raise sys.exc_info()[1] # Reraise current exception (py2.4 compliant)
-  return {"test_func" : test_func}
-
 def getstatusoutput(cmd):
-    """    Return (status, output) of executing cmd in a shell.
+    """
+    Return (status, output) of executing cmd in a shell.
 
     Execute the string 'cmd' in a shell with 'check_output' and
     return a 2-tuple (status, output). Universal newlines mode is used,
@@ -48,36 +40,25 @@ def getstatusoutput(cmd):
         data = data[:-1]
     return status, data
 
-# Main program
-#
-
-def main(home_dir=""):
-  from os.path import join as pj
-                                                                           
-  # Check if we are in the top of the ABINIT source tree
-  my_name = os.path.basename(__file__) + ".main"
-  if ( not os.path.exists( pj(home_dir,"configure.ac") ) or
-       not os.path.exists( pj(home_dir,"src/98_main/abinit.F90")) ):
-    print("%s: You must be in the top of an ABINIT source tree." % my_name)
-    print("%s: Aborting now." % my_name)
-    sys.exit(1)
 
+def main():
+  home_dir = find_abinit_toplevel_directory()
   # Init
   nerr = 0
   bex_diffs = list()
   bex_missing = list()
 
-  bex_dir = pj(home_dir,"doc/build/config-examples")
-  ref_dir = pj(home_dir,"abichecks/buildsys/Refs")
+  bex_dir = os.path.join(home_dir,"doc/build/config-examples")
+  ref_dir = os.path.join(home_dir,"abichecks/buildsys/Refs")
+  assert os.path.exists(bex_dir) and os.path.exists(ref_dir)
 
   # Check files
   ref_list = os.listdir(ref_dir)
   ref_list.sort()
   for ref_file in ref_list:
     if os.path.exists("%s/%s" % (bex_dir,ref_file)):
-      (ret,tmp) = getstatusoutput("diff  %s/%s %s/%s" % \
-        (ref_dir,ref_file,bex_dir,ref_file))
-      if ( ret != 0 ):
+      ret, tmp = getstatusoutput("diff  %s/%s %s/%s" % (ref_dir,ref_file,bex_dir,ref_file))
+      if ret != 0:
         bex_diffs.append(ref_file)
         sys.stdout.write(tmp)
     else:
@@ -88,6 +69,7 @@ def main(home_dir=""):
   # Report any mismatch
   if nerr > 0:
     sys.stderr.write("%s: reporting wrongly generated build examples\n\n" % (os.path.basename(sys.argv[0])))
+    sys.stderr.write("Reference files are in ~abinit/abichecks/buildsys")
     sys.stderr.write("X: D=Difference detected / M=Missing File\n\n")
     sys.stderr.write("%s  %-64s\n" % ("X","File"))
     sys.stderr.write("%s  %s\n" % ("-","-" * 64))
@@ -102,10 +84,4 @@ def main(home_dir=""):
   return nerr
 
 if __name__ == "__main__":
-  if len(sys.argv) == 1: 
-    home_dir = "."
-  else:
-    home_dir = sys.argv[1] 
-                               
-  exit_status = main(home_dir)
-  sys.exit(exit_status)
+  sys.exit(main())
