@@ -126,6 +126,9 @@ ABI_UNITS = [
     'Rydbergs',
     'T',
     'Tesla',
+    'Second',
+    'S',
+    'Sec',
 ]
 
 # Operators supported by parser
@@ -151,7 +154,7 @@ ABI_CHARACTERISTICS = [
 ABI_EXTERNAL_PARAMS = OrderedDict([
     ("AUTO_FROM_PSP", "Means that the value is read from the PSP file"),
     ("CUDA", "True if CUDA is enabled (compilation)"),
-    ("ETSF_IO", "True if ETSF_IO is enabled (compilation)"),
+    ("ETSF_IO", "True if NetCDF is enabled (compilation)"),
     ("FFTW3", "True if FFTW3 is enabled (compilation)"),
     ("MPI_IO", "True if MPI_IO is enabled (compilation)"),
     ("NPROC", "Number of processors used for Abinit"),
@@ -172,6 +175,7 @@ ABI_TOPICS = [
     "BandOcc",
     "BoundingProcess",
     "BSE",
+    "ConstrainedDFT",
     "ConstrainedPol",
     "Control",
     "Coulomb",
@@ -206,6 +210,7 @@ ABI_TOPICS = [
     "k-points",
     "LatticeModel",
     "LDAminushalf",
+    "longwave" ,
     "LOTF",
     "MagField",
     "MagMom",
@@ -235,9 +240,11 @@ ABI_TOPICS = [
     "SelfEnergy",
     "SmartSymm",
     "spinpolarisation",
+    "SpinDynamicsMultibinit",
     "STM",
     "Susceptibility",
     "TDDFT",
+    "a-TDEP",
     "TDepES",
     "Temperature",
     "TransPath",
@@ -272,7 +279,7 @@ ABI_RELEVANCES = OrderedDict([
 class Variable(object):
     """
     This object gathers information about a single variable. name, associated topics, description etc
-    It's constructed from the variables_CODENANE.py modules but client code usually
+    It is constructed from the variables_CODENAME.py modules but client code usually
     interact with variables via the :class:`VarDatabase` dictionary.
     """
     def __init__(self,
@@ -310,7 +317,6 @@ class Variable(object):
             commentdefault=None,
             commentdims=None,
             added_in_version (str): String with the Abinit version in which this variable was added.
-                None if variable is present in Abinit <= 8.6.3
             alternative_name: alias name (used if a new variable with a different name was introduced, in place
                 of of an old variable that is still supported.
             text: markdown string with documentation. Required.
@@ -332,7 +338,7 @@ class Variable(object):
         self.text = my_unicode(text)
 
         errors = []
-        for a in ("abivarname", "varset", "vartype", "topics", "dimensions", "text"):
+        for a in ("abivarname", "varset", "vartype", "topics", "dimensions", "added_in_version", "text"):
             if getattr(self, a) is None:
                 errors.append("attribute %s is mandatory" % a)
         if errors:
@@ -341,7 +347,7 @@ class Variable(object):
     @lazy_property
     def name(self):
         """Name of the variable without the executable name."""
-        return self.abivarname if "@" not in self.abivarname else self.abivarname.split("@")[0]
+        return self.abivarname.lower() if "@" not in self.abivarname else self.abivarname.split("@")[0].lower()
 
     @lazy_property
     def executable(self):
@@ -537,7 +543,7 @@ class Variable(object):
 
     def to_abimarkdown(self, with_hr=True):
         """
-        Return markdown string Can use Abinit markdown extensions.
+        Return markdown string. Can use Abinit markdown extensions.
         """
         lines = []; app = lines.append
 
@@ -559,6 +565,7 @@ class Variable(object):
             app("*Only relevant if:* %s  " % str(self.requires))
         if self.excludes:
             app("*The use of this variable forbids the use of:* %s  " % self.excludes)
+        app("*Added in version:* %s  " % self.added_in_version)
 
         # Add links to tests.
         if hasattr(self, "tests") and not self.is_internal:
@@ -597,7 +604,9 @@ class Variable(object):
 
         # Add text with description.
         app(2 * "\n")
-        app(self.text)
+        # Replace all occurrences of [[name]] with **name** to reduce number of html links in docs
+        new_text = self.text.replace("[[%s]]" % self.name, " **%s** " % self.name)
+        app(new_text)
         if with_hr: app("* * *" + 2*"\n")
 
         return "\n".join(lines)
@@ -653,12 +662,13 @@ class Variable(object):
         #    if not isinstance(self.varset, str) or self.varset not in ref_varset:
         #        print('The field varset of %s should be one of the valid varsets' % str(self))
 
-        if len(self.name) > 20:
-            eapp("Lenght of `%s` is longer than 20 characters." % svar)
+        if len(self.name) > 25:
+            eapp("Lenght of `%s` is longer than 25 characters." % self.name)
 
         if errors:
             raise ValueError("\n".join(errors))
 
+
 class ValueWithUnit(object):
     """
     This type allows to specify values with units:
@@ -673,6 +683,7 @@ class ValueWithUnit(object):
     def __repr__(self):
         return str(self)
 
+
 class Range(object):
     """
     Specifies a range (start:stop:step)
@@ -744,6 +755,7 @@ class MultipleValue(object):
         else:
             return str(self.number) + " * " + str(self.value)
 
+
 def my_unicode(s):
     """Convert string to unicode (needed for py2.7 DOH!)"""
     return unicode(s) if sys.version_info[0] <= 2 else str(s)
@@ -949,6 +961,8 @@ class InputVariables(OrderedDict):
         """Initialize the object from python file."""
         import imp
         module = imp.load_source(filepath, filepath)
+        #from importlib.machinery import SourceFileLoader
+        #module = SourceFileLoader(filepath, filepath).load_module()
         vlist = [Variable(**d) for d in module.variables]
         new = cls()
         new.executable = module.executable
