@@ -27,7 +27,7 @@ from pprint import pprint
 from pybtex.database import parse_file, Entry, BibliographyData
 from markdown.util import etree
 from pygments import highlight
-from pygments.lexers import BashLexer, BibTeXLexer
+from pygments.lexers import BashLexer, PythonLexer, BibTeXLexer
 from pygments.formatters import HtmlFormatter
 from doc.tests.pymods.termcolor import cprint
 from .variables import lazy_property, Variable,  ABI_TOPICS, ABI_RELEVANCES
@@ -40,8 +40,8 @@ def my_unicode(s):
 
 def escape(text, tag=None, cls=None):
     """Escape HTML entities in ``text`` string. Enclose new text in ``tag`` if tag with class ``cls``."""
-    import cgi
-    text = cgi.escape(text, quote=True)
+    import html
+    text = html.escape(text, quote=True)
     if tag:
         text = '<{tag} class="{cls}">\n{text}\n</{tag}>\n'.format(tag=tag, text=text, cls=cls if cls else "")
     return text
@@ -95,7 +95,8 @@ class MyEntry(Entry):
         """String with authors. Empty if authors are not provided."""
         try:
             #return ", ".join(my_unicode(p) for p in self.persons["author"])
-            return ", ".join( my_unicode(p).partition(',')[2]+" "+my_unicode(p).partition(',')[0] for p in self.persons["author"])
+            return ", ".join(my_unicode(p).partition(',')[2] + " " +
+                             my_unicode(p).partition(',')[0] for p in self.persons["author"])
         except KeyError:
             return ""
 
@@ -210,7 +211,7 @@ _WEBSITE = None
 
 class Website(object):
     """
-    This object is a singleton. It stores all the information required to generated the HTML documentation
+    This object is a singleton. It stores all the information required to generate the HTML documentation
     (input variables, test suite, bibtex entries).
     It also provides methods such as `get_wikilink` that will be invoked by the python markdown parser
     to implement extensions to the standard markdown syntax.
@@ -253,7 +254,10 @@ class Website(object):
         # Read mkdocs configuration file.
         # TODO: Should read Abinit version from a centralized file.
         with io.open(os.path.join(self.root, "..", "mkdocs.yml"), "rt", encoding="utf-8") as fh:
-            self.mkdocs_config = yaml.load(fh)
+            if hasattr(yaml, "FullLoader"):
+                self.mkdocs_config = yaml.load(fh, Loader=yaml.FullLoader)
+            else:
+                self.mkdocs_config = yaml.load(fh)
 
         # Build parser to convert Markdown to HTML.
         # The parser must support the same extensions as those used by mkdocs
@@ -329,7 +333,7 @@ class Website(object):
             #"conducti",
             "mrgscr",
             #"macroave",
-            "mrgdv",
+            "mrgdv", "atdep"
         ])
 
         for test in tests:
@@ -355,7 +359,7 @@ class Website(object):
 
         # Find pdf files and sort them by basename.
         self.pdfs = OrderedDict(sorted([t for t in self.walk_filepath() if t[0].endswith(".pdf")],
-            key=lambda t: t[0]))
+                                key=lambda t: t[0]))
 
         cprint("Initial website generation completed in %.2f [s]" % (time.time() - start), "green")
 
@@ -452,14 +456,14 @@ Change the input yaml files or the python code
         #with self.new_mdfile(dirname, "index.md") as mdf:
         #    mdf.write("\n".join(index_md))
 
-    def copy_readme_files(self):
+    def copy_install_files(self):
         """
-        Copy README_*.md files from ~abint to ~abinit/doc and *git ignore* them.
+        Copy INSTALL_*.md files from ~abinit to ~abinit/doc and *git ignore* them.
         Files must be included in mkdocs.yml in the `Installation` section.
         """
         top = os.path.abspath(os.path.join(self.root, ".."))
         for f in os.listdir(top):
-            if f.startswith("README_") and f.endswith(".md"):
+            if f.startswith("INSTALL_") and f.endswith(".md"):
                 src = os.path.join(top, f)
                 dest = os.path.join(self.root, f)
                 shutil.copy(src, dest)
@@ -473,15 +477,18 @@ Change the input yaml files or the python code
         app("""
 # Autoconf examples
 
-This page gathers the autoconf files used by the buildbot testfarm
+This page gathers the autoconf files used by the buildbot testfarm. The different
+bots are described in the Wiki: [slave matrix](https://wiki.abinit.org/doku.php?id=bb:slaves)
+and [builder matrix](https://wiki.abinit.org/doku.php?id=bb:builder).
 
 """)
         for f in os.listdir(dirpath):
             path = os.path.join(dirpath, f)
-            if os.path.isdir(path): continue
+            if os.path.isdir(path) or path.endswith(".swp") or path.endswith(".ac"): continue
             app("## %s  " %  f)
             with io.open(path, "rt", encoding="utf-8") as fh:
                 # Remove all comments except for options that are specified.
+                #print(path)
                 ac_lines = []
                 inblock = False
                 for l in reversed(fh.readlines()):
@@ -507,7 +514,7 @@ This page gathers the autoconf files used by the buildbot testfarm
         """Generate markdown files using the data stored in the bibtex file, the abivars file ..."""
         start = time.time()
 
-        self.copy_readme_files()
+        self.copy_install_files()
         self.generate_page_with_ac_examples()
 
         # Write index.md with the description of the input variables.
@@ -715,6 +722,8 @@ in order of number of occurrence in the input files provided with the package.
         self.analyze_pages()
 
         # Now generate page with bibliography.
+        # TODO: Should profile this part, I believe that most of the time in mkdocs in spent to convert
+        # this huge md file to html.
         cprint("Generating Markdown file with bibliographic entries ...", "green")
         citation2pages = defaultdict(list)
         for page in self.md_pages:
@@ -852,58 +861,78 @@ The bibtex file is available [here](../abiref.bib).
 
         tutorial_readme = """
 
-!!! important
+!!! note
 
-    All the necessary input files to run the examples can be found in the *~abinit/tests/* directory
-    where *~abinit* is the absolute path of the abinit top-level directory.
-
-    To execute the tutorials, you are supposed to create a working directory (`Work*`) and
-    copy there the input files and the *files* file of the lesson.
+    Supposing you made your own install of ABINIT, the input files to run the examples
+    are in the *~abinit/tests/* directory where *~abinit* is the absolute path of the abinit top-level directory.
+    If you have NOT made your own install, ask your system administrator where to find the package, especially the executable and test files.
 
+    To execute the tutorials, create a working directory (`Work*`) and
+    copy there the input files and the *files* file of the lesson. This will be explicitly mentioned in the first lessons,
+    that will tell you more about the *files* file (see also [[help:abinit#intro|section 1.1]]).
     The *files* file ending with *_x* (e.g. *tbase1_x.files*) **must be edited** every time you start to use a new input file.
-    You will discover more about the *files* file in [[help:abinit#intro|section 1.1]] of the help file.
 
-    To make things easier, we suggest to define some handy environment variables by
+    Most of the tutorials do not rely on parallelism (except specific [[tutorial:basepar|tutorials on parallelism]]).
+    However you can run most of the tutorial examples in parallel, see the [[topic:parallelism|topic on parallelism]].
+
+    In case you work on your own PC or workstation, to make things easier, we suggest you define some handy environment variables by
     executing the following lines in the terminal:
 
     ```bash
     export ABI_HOME=Replace_with_the_absolute_path_to_the_abinit_top_level_dir
-
-    export ABI_TESTS=$ABI_HOME/tests/
-
-    export ABI_TUTORIAL=$ABI_TESTS/tutorial/           # Files for base1-2-3-4, GW ...
-    export ABI_TUTORESPFN=$ABI_TESTS/tutorespfn/       # Files specific to DFPT tutorials.
-    export ABI_TUTOPARAL=$ABI_TESTS/tutoparal/         # Tutorials about parallel version
-    export ABI_TUTOPLUGS=$ABI_TESTS/tutoplugs/         # Examples using external libraries.
-    export ABI_PSPDIR=$ABI_TESTS/Psps_for_tests/       # Pseudos used in examples.
-
     export PATH=$ABI_HOME/src/98_main/:$PATH
+    export ABI_TESTS=$ABI_HOME/tests/
+    export ABI_PSPDIR=$ABI_TESTS/Psps_for_tests/  # Pseudopotentials used in examples.
     ```
 
-    The examples in this tutorial will use these shell variables so that one can easily copy and paste
-    the code snippets into the terminal (**remember to set ABI_HOME first!**)
-
-    The last line adds the directory containing the executables to your [PATH](http://www.linfo.org/path_env_var.html)
-    so that one can invoke the code by simply typing *abinit* in the terminal instead of providing the absolute path.
-
-    Finally, to run the examples in parallel with e.g. 2 MPI processes, use *mpirun* (*mpiexec*) and the syntax:
-
-        mpirun -n 2 abinit < files_file > log 2> err
-
-    The standard output of the application is redirected to `log` while `err` collects the standard error
-    (runtime error messages, if any, are written here).
+    Examples in this tutorial use these shell variables: copy and paste
+    the code snippets into the terminal (**remember to set ABI_HOME first!**).
+    The 'export PATH' line adds the directory containing the executables to your [PATH](http://www.linfo.org/path_env_var.html)
+    so that you can invoke the code by simply typing *abinit* in the terminal instead of providing the absolute path.
 
 """
+        tutorial_readmev9 = """
 
+!!! note
+
+    Supposing you made your own install of ABINIT, the input files to run the examples
+    are in the *~abinit/tests/* directory where *~abinit* is the absolute path of the abinit top-level directory.
+    If you have NOT made your own install, ask your system administrator where to find the package, especially the executable and test files.
+
+    To execute the tutorials, create a working directory (`Work*`) and
+    copy there the input files of the lesson.
+
+    Most of the tutorials do not rely on parallelism (except specific [[tutorial:basepar|tutorials on parallelism]]).
+    However you can run most of the tutorial examples in parallel, see the [[topic:parallelism|topic on parallelism]].
+
+    In case you work on your own PC or workstation, to make things easier, we suggest you define some handy environment variables by
+    executing the following lines in the terminal:
+
+    ```bash
+    export ABI_HOME=Replace_with_the_absolute_path_to_the_abinit_top_level_dir
+    export PATH=$ABI_HOME/src/98_main/:$PATH
+    export ABI_TESTS=$ABI_HOME/tests/
+    export ABI_PSPDIR=$ABI_TESTS/Psps_for_tests/  # Pseudopotentials used in examples.
+    ```
+
+    Examples in this tutorial use these shell variables: copy and paste
+    the code snippets into the terminal (**remember to set ABI_HOME first!**).
+    The 'export PATH' line adds the directory containing the executables to your [PATH](http://www.linfo.org/path_env_var.html)
+    so that you can invoke the code by simply typing *abinit* in the terminal instead of providing the absolute path.
+
+"""
         new_lines = []
         for line in lines:
             if "[TUTORIAL_README]" in line:
                 new_lines.extend(tutorial_readme.splitlines())
+            elif "[TUTORIAL_READMEV9]" in line:
+                new_lines.extend(tutorial_readmev9.splitlines())
             else:
                 new_lines.append(line)
 
         return new_lines
 
+
     def _preprocess_aliases(self, lines):
         """
         Handle aliases.
@@ -1053,7 +1082,7 @@ The bibtex file is available [here](../abiref.bib).
                 if "@" in name:
                     # Handle [[dipdip@anaddb|text]]
                     vname, code = name.split("@")
-                    var = self.codevars[code][vname]
+                    var = self.codevars[code][vname.lower()]
                     url = "/variables/%s#%s" % (var.varset, var.name)
                     if a.text is None: a.text = name
                     html_classes.append("codevar-wikilink")
@@ -1111,7 +1140,7 @@ The bibtex file is available [here](../abiref.bib).
             if namespace in self.codevars:
                 # Handle [[anaddb:asr|text]] or [[abinit:ecut|text]]
                 assert fragment is None
-                var = self.codevars[namespace][name]
+                var = self.codevars[namespace][name.lower()]
                 url = "/variables/%s#%s" % (var.varset, var.name)
                 html_classes.append("codevar-wikilink")
                 if a.text is None:
@@ -1169,7 +1198,7 @@ The bibtex file is available [here](../abiref.bib).
                     add_popover(a, content=self.howto_topic[name])
 
             elif namespace == "cite":
-                # Handle [[bib:biblio|bibliography]]
+                # Handle [[cite:biblio]]
                 if name == "biblio":
                     url = "/theory/bibliography/"
                     if a.text is None: a.text = "bibliography"
@@ -1229,14 +1258,17 @@ The bibtex file is available [here](../abiref.bib).
                 html_classes.append("abifile-wikilink")
 
             elif namespace == "ac":
-                # Handle [[ac:abiref_gnu_5.3_debug.ac]]
+                # Handle [[ac:abiref_gnu_9.2_debug.ac]]
                 # The following is incorrect: files in /build/config-examples are generated when makemake is issued.
                 # url = "/build/config-examples/%s" % name
                 # By contrast, the following is a permanent reference
-                url = "/abichecks/buildsys/Refs/%s" % name
-                if a.text is None: a.text = name
-                target = "_blank"
-                html_classes.append("abifile-wikilink")
+                # FIXME: buildsys refs are not generated anymore (YP)
+                #url = "/abichecks/buildsys/Refs/%s" % name
+                #if a.text is None: a.text = name
+                #target = "_blank"
+                #html_classes.append("abifile-wikilink")
+                url = "/build/config-template.ac9"
+                pass
 
             elif namespace == "pdf":
                 # Handle [[pdf:howto_chebfi.pdf]] or [[pdf:howto_chebfi]]
@@ -1298,7 +1330,7 @@ The bibtex file is available [here](../abiref.bib).
         return a
 
     def build_varsearch_html(self, page_rpath):
-        # Build single dictionary mapping varname --> var. Add @code if not abinit.
+        """Build single dictionary mapping varname --> var. Add @code if not abinit."""
         allvars = {}
         for code, vd in self.codevars.items():
             allvars.update({v.abivarname: v for v in vd.values()})
@@ -1309,7 +1341,7 @@ The bibtex file is available [here](../abiref.bib).
         html_vars = ""
         for char, group in sort_and_groupby(list(allvars.items()), key=lambda t: t[0][0].upper()):
             lis = "\n".join("<li>{link}</li>".format(
-                link=var.internal_link(self, page_rpath, label=var.abivarname, cls="small-grey-link")) for _, var in group)
+                link=var.internal_link(self, page_rpath, label=var.abivarname, cls="small-grey-link")) for _, var in sorted(group))
 
         #for char, group in sort_and_groupby(allvars, key=lambda t: t[0][0].upper()):
         #    group = list(group)
@@ -1349,8 +1381,9 @@ The bibtex file is available [here](../abiref.bib).
 
 ## All variables
 
-See aim, anaddb or optic for the subset of input variables for the executables AIM(Bader), ANADDB and OPTIC.
-Such input variables are specifically labelled @aim, @anaddb, or @optic in the input variable database.
+See aim, anaddb, atdep, multibinit or optic for the subset of input variables for the executables 
+AIM(Bader), ANADDB, ATDEP, MULTIBINIT and OPTIC.
+Such input variables are specifically labelled @aim, @anaddb, @atdep, @multibinit or @optic in the input variable database.
 Enter any string to search in the database. Clicking without any request will give all variables.
 
 {search_form}
@@ -1379,6 +1412,8 @@ Enter any string to search in the database. Clicking without any request will gi
         with io.open(os.path.join(self.root, path), "rt", encoding="utf-8") as fh:
             if path.endswith(".in"):
                 text = highlight(fh.read(), BashLexer(), HtmlFormatter(cssclass="codehilite small-text"))
+            elif path.endswith(".py"):
+                text = highlight(fh.read(), PythonLexer(), HtmlFormatter(cssclass="codehilite small-text"))
             else:
                 text = escape(fh.read(), tag="pre", cls="small-text")
 
