@@ -81,8 +81,6 @@ def READ_INPUT(user_filein):
                       vararray[3][0] = float(l[1])
                       if len(l)>2:
                           vararray[3][1] = GET_UNIT(l[2])
-                  elif l[0] == '':                # passes over spaces
-                      fill = 0
                   elif l[0] == 'calctype':        # calculation type
                       vararray[4] = int(l[1])
                   elif l[0] == 'outname':         # output file name
@@ -114,8 +112,17 @@ def READ_INPUT(user_filein):
         printout('Input file located and read in.\n')
                     
     #Now check that the user put a valid name in for the anaddb output file
-    check = CHECK_FILE(vararray[0])
-    if check == False:
+    # Sanity check...
+    if vararray[0] == '' : # no file name given
+        print('WARNING: No input file name given. Please try again.')
+        sys.exit()
+    elif vararray[0].endswith('.nc'):
+        print('WARNING: This program uses the output file and not a NetCDF file.')
+        sys.exit()
+    else:
+        check = CHECK_FILE(vararray[0])
+    
+    if not check:
         printout('')
         printout('The anaddb output file was not found in the directory.\n Please correct this.')
         sys.exit()
