@@ -57,7 +57,7 @@ def main():
   """
 
   header +=  '\nThis script compute the static/dynamic zero-point motion \n\
-  and the temperature dependance of eigenenergies due to electron-phonon interaction.\n\
+  and the temperature dependence of eigenenergies due to electron-phonon interaction.\n\
   The electronic lifetime can also be computed. \n\n\
   WARNING: The first Q-point MUST be the Gamma point.\n'
    
@@ -73,7 +73,7 @@ def main():
   
   # Type of calculation the user want to perform
   user_input = raw_input('Define the type of calculation you want to perform. Type:\n\
-                        1 if you want to run a non-adiabatic AHC calculation\n \
+                         1 if you want to run a non-adiabatic AHC calculation\n \
                         2 if you want to run a static AHC calculation\n \
                         3 if you want to run a static AHC calculation without control on active space (not recommended !)\n \
   Note that for 1 & 2 you need _EIGR2D.nc and _GKK.nc files obtained through ABINIT option "ieig2rf 5"\n')
@@ -237,7 +237,7 @@ def main():
             degen[ispin,ikpt,iband] = count
   
   # Create the random Q-integration (wtq=1/nqpt):
-  if (EIGR2D.wtq == 0):
+  if (abs(EIGR2D.wtq) < tol6):
     wtq = N.ones((nbQ))
     wtq = wtq*(1.0/nbQ)
   else:
@@ -264,7 +264,7 @@ def main():
                all_temp,smearing,eig0_pass,degen,energy,gaussian_smearing)
   total_corr = total.total_corr
   
-  if (EIGR2D.wtq != 0):
+  if (abs(EIGR2D.wtq) > tol6):
     total_wtq = total.total_wtq
     print("Total weigth is ",total_wtq)
     if (total_wtq < 0.9 or total_wtq > 1.1):
