@@ -34,8 +34,8 @@ inp_files = [
 "t23.in",
 "t31.in",
 "t32.in",
-"t33.in",
-"t34.in",
+"-t33.in",
+"-t34.in",
 "-t35.in",
 "-t36.in",
 ]
