@@ -10,9 +10,9 @@ keywords = [
 
 #: List of input files
 inp_files = [
-"testin_1.in",
-"testin_2.in",
-"testin_3.in",
+"testin_fast.in",
+"testin_v1.in",
+"testin_v5.in",
 "testin_bigdft.in",
 "testin_etsf_io.in",
 "testin_libxc.in",
