@@ -62,6 +62,9 @@ inp_files = [
 "t81.in",
 "t82.in",
 "t83.in",
+"t84.in",
+"-t85.in", # disabled for now
+"t86.in",
 "t91.in",
 "t92.in",
 "t93.in",
@@ -70,5 +73,5 @@ inp_files = [
 "t96.in",
 "t97.in",
 "t98.in",
-"t99.in",
+"t99.in"
 ]
