@@ -1,7 +1,18 @@
 "Yet Another Python Templating Utility, Version 1.2. Taken from http://code.activestate.com/recipes/52305/"
+from __future__ import print_function, division, absolute_import #, unicode_literals
 
 import sys
 
+from .six import exec_
+
+#def exec_(stat, globals, locals):
+#    """Comment the last line if you are using python3."""
+#    # Py2 version
+#    exec stat in globals, locals
+#    # Py3 version
+#    #exec(stat, globals, locals)
+
+
 # utility stuff to avoid tests in the mainline code
 class _nevermatch:
     "Polymorphic with a regex that never matches"
@@ -54,7 +65,7 @@ class copier:
                 stat = self.preproc(stat, 'exec')
                 stat = '%s _cb(%s,%s)' % (stat,i+1,j)
                 # for debugging, uncomment...: print "-> Executing: {"+stat+"}"
-                exec stat in self.globals,self.locals
+                exec_(stat, self.globals, self.locals)
                 i=j+1
             else:       # normal line, just copy with substitution
                 self.ouf.write(self.regex.sub(repl,line))
@@ -102,9 +113,9 @@ After all, @x@ is rather small!
   Also, @i@ times @x@ is @i*x@.
 -
 One last, plain line at the end.""".split('\n')]
-    print "*** input:"
-    print ''.join(lines_block)
-    print "*** output:"
+    print("*** input:")
+    print(''.join(lines_block))
+    print("*** output:")
     cop.copy(lines_block)
 
 
