@@ -2,7 +2,7 @@
 
 #: List of CPP variables that should be defined in config.h in order to enable this suite.
 need_cpp_vars = [
-"HAVE_DFT_WANNIER90",
+"HAVE_WANNIER90",
 ]
 
 #: List of keywords that are automatically added to all the tests of this suite. 
