@@ -4,7 +4,7 @@
 need_cpp_vars = [
 ]
 
-#: List of keywords that are automatically added to all the tests of this suite. 
+#: List of keywords that are automatically added to all the tests of this suite.
 keywords = [
 ]
 
@@ -12,10 +12,13 @@ subsuites = [
 "elast",
 "depes",
 "eph",
+"eph4mob",
+"eph4isotc",
+"eph4zpr",
 "ffield",
 "lw",
 "nlo",
-"optic",   
+"optic",
 "rf1",
 "rf2",
 ]
@@ -26,18 +29,45 @@ inp_files = [
 "tdepes_2.in",
 "tdepes_3.in",
 "tdepes_4.in",
+#
 "telast_1.in",
 "telast_2.in",
 "telast_3.in",
 "telast_4.in",
 "telast_5.in",
 "telast_6.in",
+#
 "teph_1.in",
 "teph_2.in",
 "teph_3.in",
 "teph_4.in",
 "teph_5.in",
 "teph_6.in",
+#
+"teph4mob_1.in",
+"teph4mob_2.in",
+"teph4mob_3.in",
+"teph4mob_4.in",
+"teph4mob_5.in",
+"teph4mob_6.in",
+"teph4mob_7.in",
+#
+"teph4isotc_1.in",
+#"teph4isotc_2.in",
+#"teph4isotc_3.in",
+#"teph4isotc_4.in",
+#"teph4isotc_5.in",
+#"teph4isotc_6.in",
+#
+"teph4zpr_1.in",
+"teph4zpr_2.in",
+"teph4zpr_3.in",
+"teph4zpr_4.in",
+"teph4zpr_5.in",
+"teph4zpr_6.in",
+"teph4zpr_7.in",
+"teph4zpr_8.in",
+#
 "tffield_1.in",
 "tffield_2.in",
 "tffield_3.in",
@@ -45,6 +75,7 @@ inp_files = [
 "tffield_5.in",
 "tffield_6.in",
 #"-tffield_7.in",  # Disabled
+#
 "tlw_1.in",
 "tlw_2.in",
 "tlw_3.in",
@@ -52,33 +83,37 @@ inp_files = [
 "tlw_5.in",
 "tlw_6.in",
 "tlw_7.in",
+#
 "tnlo_1.in",
 "tnlo_2.in",
 "tnlo_3.in",
 "tnlo_4.in",
 "tnlo_5.in",
-"tnlo_6.in",      
+"tnlo_6.in",
 "tnlo_7.in",
 "tnlo_8.in",
 "tnlo_9.in",
 "tnlo_10.in",
 "tnlo_11.in",
-"toptic_1.in",   
+#
+"toptic_1.in",
 "toptic_2.in",
 "toptic_3.in",
 "toptic_4.in",
 "toptic_5.in",
+#
 "trf1_1.in",
 "trf1_2.in",
 "trf1_3.in",
 "trf1_4.in",
 "trf1_5.in",
 "trf1_6.in",
+#
 "trf2_1.in",
 "trf2_2.in",
 "trf2_3.in",
 "trf2_4.in",
-"trf2_5.in",   # FIXME recheck band2eps
+"trf2_5.in",
 "trf2_6.in",
 "trf2_7.in",
 ]
