@@ -104,7 +104,7 @@ inp_files = [
 "t94.in",
 "t95.in",
 "t96.in",
-"t97.in",
-"t98.in",
-"t99.in",
+"-t97.in",
+"-t98.in",
+"-t99.in",
 ]
