@@ -19,7 +19,6 @@ inp_files = [
 "t07.in",
 "t08.in",
 "t09.in",
-"-t10.in", # ACDF is not supported anymore (requires mkmem ==0)
 "t17.in",
 "t20.in",
 "t21.in",
@@ -48,9 +47,6 @@ inp_files = [
 "t44.in",
 "t45.in",
 "t46.in",
-"t47.in",
-"t48.in",
-"t49.in",
 "t50.in", 
 "t51.in", 
 "t52.in",
